import type { NumOrString, Path } from "@thi.ng/api";
/**
 * Converts the given key path to canonical form (array).
 *
 * @remarks
 * If given path is an array, performs a safety check to ensure that all path
 * items are strings or numbers and that illegal paths like `[["__proto__"],
 * "foo"]` will be disallowed (throws an error).
 *
 * Also see {@link disallowProtoPath}.
 *
 * ```ts
 * import { toPath } from "@thi.ng/paths";
 *
 * toPath("a.b.c");
 * // ["a", "b", "c"]
 *
 * toPath(0)
 * // [0]
 *
 * toPath(["a", "b", "c"])
 * // ["a", "b", "c"]
 * ```
 *
 * @param path -
 */
export declare const toPath: (path: Path) => readonly NumOrString[];
/**
 * Takes an arbitrary object and lookup path. Descends into object along
 * path and returns true if the full path exists (even if final leaf
 * value is `null` or `undefined`). Checks are performed using
 * `hasOwnProperty()`.
 *
 * @param obj -
 * @param path -
 */
export declare const exists: (obj: any, path: Path) => boolean;
/**
 * Helper function. First converts given `path` using {@link toPath} and then
 * analyzes it via
 * [`isProtoPath()`](https://docs.thi.ng/umbrella/checks/functions/isProtoPath.html).
 * Throws an error if path contains any property which might lead to prototype
 * poisoning. Returns converted path if valid.
 *
 * @remarks
 * The following properties are considered illegal.
 *
 * - `__proto__`
 * - `prototype`
 * - `constructor`
 *
 * @param path -
 */
export declare const disallowProtoPath: (path: Path) => readonly NumOrString[];
//# sourceMappingURL=path.d.ts.map